summaryrefslogtreecommitdiffstats
path: root/net
diff options
context:
space:
mode:
Diffstat (limited to 'net')
-rw-r--r--net/socket/tcp_pinger.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/net/socket/tcp_pinger.h b/net/socket/tcp_pinger.h
index 37ad881..0b0bd9b 100644
--- a/net/socket/tcp_pinger.h
+++ b/net/socket/tcp_pinger.h
@@ -41,9 +41,9 @@ class TCPPinger {
}
int Ping() {
// Default is 40 tries, each with a timeout of 250ms,
// for a total max timeout of 10 seconds.
- return Ping(base::TimeDelta::FromMilliseconds(250), 40);
+ return Ping(base::TimeDelta::FromMilliseconds(1000), 10);
}
int Ping(base::TimeDelta tryTimeout, int nTries) {
@@ -41,9 +41,9 @@ class TCPPinger {
}
int Ping() {
- // Default is 40 tries, each with a timeout of 250ms,
+ // Default is 10 tries, each with a timeout of 1000ms,
// for a total max timeout of 10 seconds.